################
Conversion class
################

.. |br| raw:: html

   <br />

Conversion components convert commodities into each other.

**Conversion class description:**

.. automodule:: conversion
.. autoclass:: Conversion
   :members:
   :member-order: bysource

   .. automethod:: __init__

*Inheritance diagram:*

.. inheritance-diagram:: Conversion
   :parts: 1

|

**ConversionModel class description:**

.. autoclass:: ConversionModel
   :members:
   :member-order: bysource

*Inheritance diagram:*

.. inheritance-diagram:: ConversionModel
   :parts: 1